part of 'detail_category_cubit.dart';
abstract class RowDetailCategoryState extends Equatable{
  RowDetailCategoryState();
  @override
  List<Object> get props => [];
}

class DetailCategoryInitial extends RowDetailCategoryState {
  @override
  String toString() {
    return 'DetailCategoryInitial{}';
  }
}
class DetailCategoryLoading extends RowDetailCategoryState {
  DetailCategoryLoading();

  @override
  String toString() => 'DetailCategoryLoading';
}
class DetailCategoryFailure extends RowDetailCategoryState {
  final String error;

  DetailCategoryFailure(this.error);

  @override
  String toString() => 'ChangePassFailure { error: $error }';
}
class GetDetailCategorySuccess extends RowDetailCategoryState {

  @override
  String toString() => 'GetDetailCategorySuccess';
//
}

